Index: trunk/psLib/src/collections/psArray.c
===================================================================
--- trunk/psLib/src/collections/psArray.c	(revision 2055)
+++ trunk/psLib/src/collections/psArray.c	(revision 2204)
@@ -9,6 +9,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.16 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-09-28 23:26:48 $
+ *  @version $Revision: 1.17 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -42,5 +42,5 @@
 
 /*****************************************************************************/
-psArray* psArrayAlloc(unsigned int nalloc)
+psArray* psArrayAlloc(psU32 nalloc)
 {
     psArray* psArr = NULL;
@@ -54,10 +54,10 @@
 
     // Create vector data array
-    psArr->data = psAlloc(nalloc * sizeof(psPTR));
+    psArr->data = psAlloc(nalloc * sizeof(psPtr));
 
     return psArr;
 }
 
-psArray* psArrayRealloc(psArray* restrict in, unsigned int nalloc)
+psArray* psArrayRealloc(psArray* restrict in, psU32 nalloc)
 {
     if (in == NULL) {
@@ -65,5 +65,5 @@
     } else if (in->nalloc != nalloc) {     // No need to realloc to same size
         if (nalloc < in->n) {
-            for (int i = nalloc; i < in->n; i++) {      // For reduction in vector size
+            for (psS32 i = nalloc; i < in->n; i++) {      // For reduction in vector size
                 psFree(in->data[i]);
             }
@@ -71,5 +71,5 @@
         }
         // Realloc after decrementation to avoid accessing freed array elements
-        in->data = psRealloc(in->data, nalloc * sizeof(psPTR));
+        in->data = psRealloc(in->data, nalloc * sizeof(psPtr));
         in->nalloc = nalloc;
     }
@@ -89,8 +89,8 @@
 }
 
-bool psArrayRemove(psArray* psArr,
-                   psPTR data)
+psBool psArrayRemove(psArray* psArr,
+                     psPtr data)
 {
-    bool success = false;
+    psBool success = false;
 
     if (psArr == NULL) {
@@ -98,9 +98,9 @@
     }
 
-    int n = psArr->n;
-    psPTR* psArrData = psArr->data;
-    for (int i = n-1; i<0; i--) {
+    psS32 n = psArr->n;
+    psPtr* psArrData = psArr->data;
+    for (psS32 i = n-1; i<0; i--) {
         if (psArrData[i] == data) {
-            memmove(psArrData[i],psArrData[i+1],(n-i-1)*sizeof(psPTR));
+            memmove(psArrData[i],psArrData[i+1],(n-i-1)*sizeof(psPtr));
             n--;
             success = true;
@@ -119,5 +119,5 @@
     }
 
-    for (int i = 0; i < psArr->n; i++) {
+    for (psS32 i = 0; i < psArr->n; i++) {
         psFree(psArr->data[i]);
         psArr->data[i] = NULL;
@@ -131,5 +131,5 @@
     }
 
-    qsort(in->data, in->n, sizeof(psPTR), (int (*)(const void *, const void *))compare);
+    qsort(in->data, in->n, sizeof(psPtr), (int (*)(const void* , const void*))compare);
 
     return in;
Index: trunk/psLib/src/collections/psArray.h
===================================================================
--- trunk/psLib/src/collections/psArray.h	(revision 2055)
+++ trunk/psLib/src/collections/psArray.h	(revision 2204)
@@ -12,6 +12,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.17 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-09-28 23:26:48 $
+ *  @version $Revision: 1.18 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -20,6 +20,4 @@
 #ifndef PS_ARRAY_H
 #define PS_ARRAY_H
-
-#include<stdbool.h>
 
 #include "psType.h"
@@ -36,7 +34,7 @@
 typedef struct
 {
-    unsigned int nalloc;        ///< Total number of elements available.
-    unsigned int n;             ///< Number of elements in use.
-    psPTR* data;                ///< An Array of pointer elements
+    psU32 nalloc;        ///< Total number of elements available.
+    psU32 n;             ///< Number of elements in use.
+    psPtr* data;                ///< An Array of pointer elements
 }
 psArray;
@@ -57,5 +55,5 @@
  */
 psArray* psArrayAlloc(
-    unsigned int nalloc                ///< Total number of elements to make available.
+    psU32 nalloc                ///< Total number of elements to make available.
 );
 
@@ -70,5 +68,5 @@
 psArray* psArrayRealloc(
     psArray* restrict psArr,           ///< array to reallocate.
-    unsigned int nalloc                ///< Total number of elements to make available.
+    psU32 nalloc                ///< Total number of elements to make available.
 );
 
@@ -81,7 +79,7 @@
  *
  */
-bool psArrayRemove(
+psBool psArrayRemove(
     psArray* psArr,                    ///< array to operate on
-    psPTR data                         ///< the data pointer to remove from psArray
+    psPtr data                         ///< the data pointer to remove from psArray
 );
 
Index: trunk/psLib/src/collections/psBitSet.c
===================================================================
--- trunk/psLib/src/collections/psBitSet.c	(revision 2055)
+++ trunk/psLib/src/collections/psBitSet.c	(revision 2204)
@@ -11,6 +11,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.18 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-09-21 23:17:52 $
+ *  @version $Revision: 1.19 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -21,5 +21,4 @@
 #include <ctype.h>
 #include <math.h>
-#include <stdbool.h>
 
 #include "psBitSet.h"
@@ -48,5 +47,5 @@
  *  @return  char*: Pointer to byte in which bit is contained.
  */
-static char mask(int bit)
+static char mask(psS32 bit)
 {
     char mask = (char)0x01;
@@ -67,7 +66,7 @@
 }
 
-psBitSet* psBitSetAlloc(int n)
-{
-    int numBytes = 0;
+psBitSet* psBitSetAlloc(psS32 n)
+{
+    psS32 numBytes = 0;
     psBitSet* newObj = NULL;
 
@@ -95,5 +94,5 @@
 
 psBitSet* psBitSetSet(psBitSet* inBitSet,
-                      int bit)
+                      psS32 bit)
 {
     char *byte = NULL;
@@ -120,5 +119,5 @@
 
 psBitSet* psBitSetClear(psBitSet* inBitSet,
-                        int bit)
+                        psS32 bit)
 {
     char *byte = NULL;
@@ -144,6 +143,6 @@
 }
 
-bool psBitSetTest(const psBitSet* inBitSet,
-                  int bit)
+psBool psBitSetTest(const psBitSet* inBitSet,
+                    psS32 bit)
 {
     char *byte = NULL;
@@ -173,10 +172,10 @@
                      const psBitSet* restrict inBitSet2)
 {
-    int i = 0;
-    int n = 0;
+    psS32 i = 0;
+    psS32 n = 0;
     char* outBits = NULL;
     char* inBits1 = NULL;
     char* inBits2 = NULL;
-    int op = UNKNOWN_OP;
+    psS32 op = UNKNOWN_OP;
 
     if (inBitSet1 == NULL) {
@@ -198,8 +197,8 @@
 
     // make operator all caps
-    int tempStrLen = strlen(operator);
+    psS32 tempStrLen = strlen(operator);
     char* tempStr = psAlloc(tempStrLen+1);
 
-    for (int lcv=0;lcv<tempStrLen;lcv++) {
+    for (psS32 lcv=0;lcv<tempStrLen;lcv++) {
         tempStr[lcv] = (char)toupper(operator[lcv]);
     }
@@ -308,6 +307,6 @@
 char *psBitSetToString(const psBitSet* restrict inBitSet)
 {
-    int i = 0;
-    int numBits = inBitSet->n * 8;
+    psS32 i = 0;
+    psS32 numBits = inBitSet->n * 8;
     char *outString = psAlloc((size_t) numBits + 1);
 
Index: trunk/psLib/src/collections/psBitSet.h
===================================================================
--- trunk/psLib/src/collections/psBitSet.h	(revision 2055)
+++ trunk/psLib/src/collections/psBitSet.h	(revision 2204)
@@ -12,6 +12,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.14 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-09-14 20:01:52 $
+ *  @version $Revision: 1.15 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -20,4 +20,6 @@
 #ifndef PSBITSET_H
 #define PSBITSET_H
+
+#include "psType.h"
 
 /// @addtogroup BitSet
@@ -35,5 +37,5 @@
 typedef struct
 {
-    int n;                             ///< Number of bytes in the array
+    psS32 n;                             ///< Number of bytes in the array
     char *bits;                        ///< Aray of bytes holding bits
 }
@@ -54,5 +56,5 @@
 /*@null@*/
 psBitSet* psBitSetAlloc(
-    int n                              ///< Number of bits in psBitSet array
+    psS32 n                              ///< Number of bits in psBitSet array
 );
 
@@ -68,5 +70,5 @@
     /* @returned@ */
     psBitSet* restrict inMask,         ///< Pointer to psBitSet to be set.
-    int bit                            ///< Bit to be set.
+    psS32 bit                            ///< Bit to be set.
 );
 
@@ -82,5 +84,5 @@
     /* @returned@ */
     psBitSet* restrict inMask,         ///< Pointer to psBitSet to be cleared.
-    int bit                            ///< Bit to be cleared.
+    psS32 bit                            ///< Bit to be cleared.
 );
 
@@ -95,7 +97,7 @@
  */
 
-bool psBitSetTest(
+psBool psBitSetTest(
     const psBitSet* restrict inMask,   ///< Pointer psBitSet to be tested.
-    int bit                            ///< Bit to be tested.
+    psS32 bit                            ///< Bit to be tested.
 );
 
Index: trunk/psLib/src/collections/psCompare.c
===================================================================
--- trunk/psLib/src/collections/psCompare.c	(revision 2055)
+++ trunk/psLib/src/collections/psCompare.c	(revision 2204)
@@ -7,11 +7,10 @@
  *  @author Robert Daniel DeSonia, MHPCC
  *
- *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-08-07 00:06:06 $
+ *  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
  */
 
-#include "psType.h"
 #include "psCompare.h"
 
Index: trunk/psLib/src/collections/psCompare.h
===================================================================
--- trunk/psLib/src/collections/psCompare.h	(revision 2055)
+++ trunk/psLib/src/collections/psCompare.h	(revision 2204)
@@ -1,17 +1,19 @@
+/** @file psCompare.h
+ *  @brief Comparison functions for sorting routines
+ *
+ *  @author Robert Daniel DeSonia, MHPCC
+ *
+ *  @ingroup Compare
+ *
+ *  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
+ *
+ *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
+ */
+
 #if !defined(PS_COMPARE_H)
 #define PS_COMPARE_H
 
-/** @file psCompare.h
- *  @brief Comparison functions for sorting routines
- *
- *  @author Robert Daniel DeSonia, MHPCC
- *
- *  @ingroup Compare
- *
- *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-08-11 19:58:11 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- */
+#include "psType.h"
 
 /** @addtogroup Compare
Index: trunk/psLib/src/collections/psHash.c
===================================================================
--- trunk/psLib/src/collections/psHash.c	(revision 2055)
+++ trunk/psLib/src/collections/psHash.c	(revision 2204)
@@ -11,6 +11,6 @@
 *  @author George Gusciora, MHPCC
 *
-*  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-09-21 23:17:53 $
+*  @version $Revision: 1.6 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-27 00:57:31 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -19,5 +19,4 @@
 #include <stdio.h>
 #include <string.h>
-#include <stdbool.h>
 #include "psHash.h"
 #include "psMemory.h"
@@ -29,7 +28,7 @@
 #include "psCollectionsErrors.h"
 
-static psHashBucket* hashBucketAlloc(const char *key, void *data, psHashBucket* next);
+static psHashBucket* hashBucketAlloc(const char *key, psPtr data, psHashBucket* next);
 static void hashBucketFree(psHashBucket* bucket);
-static void *doHashWork(psHash* table, const char *key, void *data, bool remove
+static psPtr doHashWork(psHash* table, const char *key, psPtr data, psBool remove
                            );
 static void hashFree(psHash* table);
@@ -45,5 +44,5 @@
 psList* psHashKeyList(psHash* table)
 {
-    int i = 0;                  // Loop index variable
+    psS32 i = 0;                  // Loop index variable
     psList* myLinkList = NULL;  // The output data structure
     psHashBucket* ptr = NULL;   // Used to step thru linked list.
@@ -85,5 +84,5 @@
  *****************************************************************************/
 static psHashBucket* hashBucketAlloc(const char *key,
-                                     void *data,
+                                     psPtr data,
                                      psHashBucket* next)
 {
@@ -135,7 +134,7 @@
     The new hash table.
  *****************************************************************************/
-psHash* psHashAlloc(int nbucket)        // initial number of buckets
-{
-    int i = 0;                  // loop index variable
+psHash* psHashAlloc(psS32 nbucket)        // initial number of buckets
+{
+    psS32 i = 0;                  // loop index variable
 
     // Create the new hash table.
@@ -172,5 +171,5 @@
 static void hashFree(psHash* table)
 {
-    int i = 0;                  // Loop index variable.
+    psS32 i = 0;                  // Loop index variable.
 
     if (table == NULL) {
@@ -212,10 +211,10 @@
 there is little common code between those functions.
   *****************************************************************************/
-static void *doHashWork(psHash* table,
+static psPtr doHashWork(psHash* table,
                         const char *key,
-                        void *data, bool remove
+                        psPtr data, psBool remove
                            )
 {
-    long int hash = 1;          // This will contain an integer value
+    psS64 hash = 1;          // This will contain an integer value
 
     // "hashed" from the key.
@@ -236,5 +235,5 @@
     }
     // NOTE: This is the originally supplied hash function.
-    // for (int i = 0, len = strlen(key); i < len; i++) {
+    // for (psS32 i = 0, len = strlen(key); i < len; i++) {
     // hash = (hash << 1) ^ key[i];
     // }
@@ -273,5 +272,5 @@
                     // of removing an item from a single-linked list.
 
-                    void *data = ptr->data;
+                    psPtr data = ptr->data;
 
                     optr->next = ptr->next;
@@ -344,7 +343,7 @@
     boolean value defining success or failure
  *****************************************************************************/
-bool psHashAdd(psHash* table,
-               const char *key,
-               void *data)
+psBool psHashAdd(psHash* table,
+                 const char *key,
+                 psPtr data)
 {
     if (table == NULL) {
@@ -380,5 +379,5 @@
     The data associated with that key.
  *****************************************************************************/
-void *psHashLookup(psHash* table,      // table to lookup key in
+psPtr psHashLookup(psHash* table,      // table to lookup key in
                    const char *key)     // key to lookup
 {
@@ -409,9 +408,9 @@
     boolean value defining success or failure
  *****************************************************************************/
-bool psHashRemove(psHash* table,
-                  const char *key)
-{
-    void *data = NULL;
-    bool retVal = false;
+psBool psHashRemove(psHash* table,
+                    const char *key)
+{
+    psPtr data = NULL;
+    psBool retVal = false;
 
     if (table == NULL) {
Index: trunk/psLib/src/collections/psHash.h
===================================================================
--- trunk/psLib/src/collections/psHash.h	(revision 2055)
+++ trunk/psLib/src/collections/psHash.h	(revision 2204)
@@ -11,6 +11,6 @@
  *  @author George Gusciora, MHPCC
  *   
- *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-08-09 23:40:55 $
+ *  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -22,5 +22,4 @@
  *  \{
  */
-#include<stdbool.h>
 
 #include "psList.h"
@@ -30,5 +29,5 @@
 {
     char *key;                  ///< key for this item of data
-    void *data;                 ///< the data itself
+    psPtr data;                 ///< the data itself
     struct psHashBucket* next;  ///< list of other possible keys
 }
@@ -40,5 +39,5 @@
 typedef struct psHash
 {
-    int nbucket;                ///< Number of buckets in hash table.
+    psS32 nbucket;                ///< Number of buckets in hash table.
     psHashBucket* *buckets;     ///< The bucket data.
 }
@@ -46,22 +45,22 @@
 
 /// Allocate hash buckets in table.
-psHash* psHashAlloc(int nbucket ///< The number of buckets to allocate.
+psHash* psHashAlloc(psS32 nbucket ///< The number of buckets to allocate.
                    );
 
 /// Insert entry into table.
-bool psHashAdd(psHash* table,  ///< table to insert in
-               const char *key, ///< key to use
-               void *data       ///< data to insert
-              );
+psBool psHashAdd(psHash* table,  ///< table to insert in
+                 const char *key, ///< key to use
+                 psPtr data       ///< data to insert
+                );
 
 /// Lookup key in table.
-void *psHashLookup(psHash* table,      ///< table to lookup key in
+psPtr psHashLookup(psHash* table,      ///< table to lookup key in
                    const char *key      ///< key to lookup
                   );
 
 /// Remove key from table.
-bool psHashRemove(psHash* table,       ///< table to lookup key in
-                  const char *key       ///< key to lookup
-                 );
+psBool psHashRemove(psHash* table,       ///< table to lookup key in
+                    const char *key       ///< key to lookup
+                   );
 
 /// List all keys in table.
Index: trunk/psLib/src/collections/psList.c
===================================================================
--- trunk/psLib/src/collections/psList.c	(revision 2055)
+++ trunk/psLib/src/collections/psList.c	(revision 2204)
@@ -6,6 +6,6 @@
  *  @author Robert Daniel DeSonia, MHPCC
  *
- *  @version $Revision: 1.19 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-09-14 20:01:52 $
+ *  @version $Revision: 1.20 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -13,5 +13,4 @@
 
 #include <stdlib.h>
-#include <stdbool.h>
 #include <stdio.h>
 #include <pthread.h>                       // we need a mutex to make this stuff thread safe.
@@ -26,14 +25,14 @@
 #include "psCollectionsErrors.h"
 
-#define ITER_INIT_HEAD ((void *)1)         // next iteration should return head
-#define ITER_INIT_TAIL ((void *)2)         // next iteration should return tail
+#define ITER_INIT_HEAD ((psPtr )1)         // next iteration should return head
+#define ITER_INIT_TAIL ((psPtr )2)         // next iteration should return tail
 
 // private functions.
 static psListElem* listGetIterator(psList* list);
-static int listGetIteratorIndex(psList* list);
-static void listSetIterator(psList* list, int where, bool lockList);
+static psS32 listGetIteratorIndex(psList* list);
+static void listSetIterator(psList* list, psS32 where, psBool lockList);
 static void listFree(psList* list);
 
-psList* psListAlloc(void *data)
+psList* psListAlloc(psPtr data)
 {
     psList* list = psAlloc(sizeof(psList));
@@ -82,9 +81,9 @@
 }
 
-bool psListAdd(psList* list, int location, void *data)
+psBool psListAdd(psList* list, psS32 location, psPtr data)
 {
     psListElem* position;
     psListElem* elem;
-    int cursorIndex = 0;
+    psS32 cursorIndex = 0;
 
     if (list == NULL) {
@@ -168,8 +167,8 @@
  * Remove an element from a list
  */
-bool psListRemove(psList* list, int location, void *data)
+psBool psListRemove(psList* list, psS32 location, psPtr data)
 {
     psListElem* elem = NULL;    // element to remove
-    int cursorIndex = 0;
+    psS32 cursorIndex = 0;
 
     if (list == NULL) {
@@ -184,5 +183,5 @@
         // search list for the data item.
 
-        int i = 0;              // index
+        psS32 i = 0;              // index
 
         for (psListElem* ptr = list->head; ptr != NULL; ptr = ptr->next) {
@@ -247,13 +246,13 @@
 }
 
-void psListSetIterator(psList* list, int where)
+void psListSetIterator(psList* list, psS32 where)
 {
     listSetIterator(list, where, true);
 }
 
-static void listSetIterator(psList* list, int where, bool lockList)
+static void listSetIterator(psList* list, psS32 where, psBool lockList)
 {
     psListElem* cursor;
-    int position;
+    psS32 position;
 
     if (list == NULL) {
@@ -272,5 +271,5 @@
     }
 
-    if (where >= (int)list->size) {
+    if (where >= (psS32)list->size) {
         list->iter = NULL;
         if (lockList) {
@@ -323,16 +322,16 @@
             }
 
-            int position = listGetIteratorIndex(list);
+            psS32 position = listGetIteratorIndex(list);
 
             if (where < position) {
-                int diff = position - where;
-
-                for (int count = 0; count < diff; count++) {
+                psS32 diff = position - where;
+
+                for (psS32 count = 0; count < diff; count++) {
                     listSetIterator(list, PS_LIST_PREVIOUS, false);
                 }
             } else {
-                int diff = where - position;
-
-                for (int count = 0; count < diff; count++) {
+                psS32 diff = where - position;
+
+                for (psS32 count = 0; count < diff; count++) {
                     listSetIterator(list, PS_LIST_NEXT, false);
                 }
@@ -363,5 +362,5 @@
 }
 
-int listGetIteratorIndex(psList* list)
+psS32 listGetIteratorIndex(psList* list)
 {
     if (list->iter == ITER_INIT_HEAD) {
@@ -374,5 +373,5 @@
 }
 
-void *psListGet(psList* list, int location)
+psPtr psListGet(psList* list, psS32 location)
 {
     psListElem* element;
@@ -391,15 +390,15 @@
  * and now return the previous/next element of the list
  */
-void *psListGetNext(psList* list)
+psPtr psListGetNext(psList* list)
 {
     return psListGet(list, PS_LIST_NEXT);
 }
 
-void *psListGetPrevious(psList* list)
+psPtr psListGetPrevious(psList* list)
 {
     return psListGet(list, PS_LIST_PREVIOUS);
 }
 
-void *psListGetCurrent(psList* list)
+psPtr psListGetCurrent(psList* list)
 {
     return psListGet(list, PS_LIST_CURRENT);
@@ -412,5 +411,5 @@
 {
     psListElem* ptr;
-    unsigned int n;
+    psU32 n;
     psArray* restrict arr;
 
@@ -429,5 +428,5 @@
     ptr = list->head;
     n = list->size;
-    for (int i = 0; i < n; i++) {
+    for (psS32 i = 0; i < n; i++) {
         arr->data[i] = psMemIncrRefCounter(ptr->data);
         ptr = ptr->next;
@@ -439,5 +438,5 @@
 psList* psArrayToList(psArray* arr)
 {
-    unsigned int n;
+    psU32 n;
     psList* list;               // list of elements
 
@@ -448,5 +447,5 @@
     list = psListAlloc(NULL);
     n = arr->n;
-    for (int i = 0; i < n; i++) {
+    for (psS32 i = 0; i < n; i++) {
         psListAdd(list, PS_LIST_TAIL, arr->data[i]);
     }
Index: trunk/psLib/src/collections/psMetadata.c
===================================================================
--- trunk/psLib/src/collections/psMetadata.c	(revision 2055)
+++ trunk/psLib/src/collections/psMetadata.c	(revision 2204)
@@ -12,6 +12,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.34 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-09 03:05:53 $
+*  @version $Revision: 1.35 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-27 00:57:30 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -59,5 +59,5 @@
 /*****************************************************************************/
 
-static int metadataId = 0;
+static psS32 metadataId = 0;
 
 /*****************************************************************************/
@@ -143,5 +143,5 @@
 
     // Set metadata item unique id
-    *(int *)(&metadataItem->id) = ++metadataId;
+    *(psS32 *)(&metadataItem->id) = ++metadataId;
 
     // Set metadata item type
@@ -154,5 +154,5 @@
         break;
     case PS_META_BOOL:
-        metadataItem->data.B = (bool)va_arg(argPtr, int);
+        metadataItem->data.B = (psBool)va_arg(argPtr, psS32);
         break;
     case PS_META_S32:
@@ -215,5 +215,5 @@
 }
 
-bool psMetadataAddItem( psMetadata *restrict md, psMetadataItem *restrict metadataItem, int location )
+psBool psMetadataAddItem( psMetadata *restrict md, psMetadataItem *restrict metadataItem, psS32 location )
 {
     char * key = NULL;
@@ -337,6 +337,6 @@
 }
 
-bool psMetadataAdd(psMetadata* restrict md, int where, const char *name, psMetadataType type,
-                   const char *comment, ...)
+psBool psMetadataAdd(psMetadata* restrict md, psS32 where, const char *name, psMetadataType type,
+                     const char *comment, ...)
 {
     va_list argPtr;
@@ -359,7 +359,7 @@
 }
 
-bool psMetadataRemove(psMetadata* restrict md, int where, const char *restrict key)
-{
-    int numChildren = 0;
+psBool psMetadataRemove(psMetadata* restrict md, psS32 where, const char *restrict key)
+{
+    psS32 numChildren = 0;
     psList* mdList = NULL;
     psHash* mdTable = NULL;
@@ -471,5 +471,5 @@
 }
 
-psMetadataItem* psMetadataGet(psMetadata* restrict md, int where)
+psMetadataItem* psMetadataGet(psMetadata* restrict md, psS32 where)
 {
     psList* mdList = NULL;
@@ -497,5 +497,5 @@
 }
 
-bool psMetadataSetIterator(psMetadata* restrict md, int where)
+psBool psMetadataSetIterator(psMetadata* restrict md, psS32 where)
 {
     psList* mdList = NULL;
@@ -517,5 +517,5 @@
 }
 
-psMetadataItem* psMetadataGetNext(psMetadata* restrict md, const char *restrict match, int which)
+psMetadataItem* psMetadataGetNext(psMetadata* restrict md, const char *restrict match, psS32 which)
 {
     psList* mdList = NULL;
@@ -553,5 +553,5 @@
 }
 
-psMetadataItem* psMetadataGetPrevious(psMetadata* restrict md, const char *restrict match, int which)
+psMetadataItem* psMetadataGetPrevious(psMetadata* restrict md, const char *restrict match, psS32 which)
 {
     psList* mdList = NULL;
Index: trunk/psLib/src/collections/psMetadata.h
===================================================================
--- trunk/psLib/src/collections/psMetadata.h	(revision 2055)
+++ trunk/psLib/src/collections/psMetadata.h	(revision 2204)
@@ -11,6 +11,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.23 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-06 01:06:27 $
+*  @version $Revision: 1.24 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-27 00:57:30 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -38,11 +38,11 @@
     PS_META_F32,                       ///< Single-precision float data.
     PS_META_F64,                       ///< Double-precision float data.
-    PS_META_STR,                       ///< String data (Stored in as void *).
-    PS_META_VEC,                       ///< Vector data (Stored in as void *).
-    PS_META_IMG,                       ///< Image data (Stored in as void *).
-    PS_META_JPEG,                      ///< JPEG data (Stored in as void *).
-    PS_META_PNG,                       ///< PNG data (Stored in as void *).
-    PS_META_ASTROM,                    ///< Astrometric coefficients (Stored in as void *).
-    PS_META_UNKNOWN,                   ///< Other data (Stored in as void *).
+    PS_META_STR,                       ///< String data (Stored in as psPtr ).
+    PS_META_VEC,                       ///< Vector data (Stored in as psPtr ).
+    PS_META_IMG,                       ///< Image data (Stored in as psPtr ).
+    PS_META_JPEG,                      ///< JPEG data (Stored in as psPtr ).
+    PS_META_PNG,                       ///< PNG data (Stored in as psPtr ).
+    PS_META_ASTROM,                    ///< Astrometric coefficients (Stored in as psPtr ).
+    PS_META_UNKNOWN,                   ///< Other data (Stored in as psPtr ).
     PS_META_NTYPE                      ///< Number of types. Must be last.
 } psMetadataType;
@@ -55,13 +55,13 @@
 typedef struct psMetadataItem
 {
-    const int id;                      ///< Unique ID for metadata item.
+    const psS32 id;                      ///< Unique ID for metadata item.
     char *restrict name;               ///< Name of metadata item.
     psMetadataType type;               ///< Type of metadata item.
     union {
-        bool B;                        ///< boolean data
+        psBool B;                        ///< boolean data
         psS32 S32;                     ///< Signed 32-bit integer data.
         psF32 F32;                     ///< Single-precision float data.
         psF64 F64;                     ///< Double-precision float data.
-        psPTR V;                       ///< Pointer to other type of data.
+        psPtr V;                       ///< Pointer to other type of data.
     } data;                            ///< Union for data types.
     char *comment;                     ///< Optional comment ("", not NULL).
@@ -144,8 +144,8 @@
  *  @return bool: True for success, false for failure.
  */
-bool psMetadataAddItem(
+psBool psMetadataAddItem(
     psMetadata* restrict md,           ///< Metadata collection to insert metadat item.
     psMetadataItem* restrict item,     ///< Metadata item to be added.
-    int location                       ///< Location to be added.
+    psS32 location                       ///< Location to be added.
 );
 
@@ -156,7 +156,7 @@
  * @return bool: True for success, false for failure.
  */
-bool psMetadataAdd(
-    psMetadata* restrict md,           ///< Metadata collection to insert metadat item.
-    int where,                         ///< Location to be added.
+psBool psMetadataAdd(
+    psMetadata* restrict md,           ///< Metadata collection to insert metadat item.
+    psS32 where,                         ///< Location to be added.
     const char *name,                  ///< Name of metadata item.
     psMetadataType type,               ///< Type of metadata item.
@@ -175,7 +175,7 @@
  * @return bool: True for success, false for failure.
  */
-bool psMetadataRemove(
-    psMetadata* restrict md,           ///< Metadata collection to insert metadat item.
-    int where,                         ///< Location to be removed.
+psBool psMetadataRemove(
+    psMetadata* restrict md,           ///< Metadata collection to insert metadat item.
+    psS32 where,                         ///< Location to be removed.
     const char *restrict key           ///< Name of metadata key.
 );
@@ -203,5 +203,5 @@
 psMetadataItem* psMetadataGet(
     psMetadata* restrict md,           ///< Metadata collection to insert metadat item.
-    int where                          ///< Location to be retrieved.
+    psS32 where                          ///< Location to be retrieved.
 );
 
@@ -213,7 +213,7 @@
  * @return void: void.
  */
-bool psMetadataSetIterator(
+psBool psMetadataSetIterator(
     psMetadata* restrict md,           ///< Metadata collection to iterate.
-    int where                          ///< Location of iterator.
+    psS32 where                          ///< Location of iterator.
 );
 
@@ -227,5 +227,5 @@
     psMetadata* restrict md,           ///< Metadata collection to iterate.
     const char *restrict match,        ///< Beginning of key name.
-    int which                          ///< Iterator to be used.
+    psS32 which                          ///< Iterator to be used.
 );
 
@@ -239,5 +239,5 @@
     psMetadata* restrict md,           ///< Metadata collection to iterate.
     const char *restrict match,        ///< Beginning of key name.
-    int which                          ///< Iterator to be used.
+    psS32 which                          ///< Iterator to be used.
 );
 
Index: trunk/psLib/src/collections/psMetadataIO.c
===================================================================
--- trunk/psLib/src/collections/psMetadataIO.c	(revision 2055)
+++ trunk/psLib/src/collections/psMetadataIO.c	(revision 2204)
@@ -9,6 +9,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.6 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-08 00:43:12 $
+*  @version $Revision: 1.7 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-27 00:57:30 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -104,5 +104,5 @@
 /** Determines if a line is blank (whitespace only) or a commentline. It returns true if so. The input string
  *  must be null terminated. */
-bool ignoreLine(char *inString)
+psBool ignoreLine(char *inString)
 {
     while(*inString!='\0' && *inString!='#') {
@@ -119,5 +119,5 @@
 /** Removes leading and trailing whitespace and # characters from a string. The cleaned string is a new null
  *  terminated copy of the original input string. */
-char *cleanString(char *inString, int sLen)
+char *cleanString(char *inString, psS32 sLen)
 {
     char *ptrB = NULL;
@@ -149,7 +149,7 @@
 
 /** Count repeat occurances of a single character within a line. The input string must be null terminated. */
-int repeatedChars(char *inString, char ch)
-{
-    int count = 0;
+psS32 repeatedChars(char *inString, char ch)
+{
+    psS32 count = 0;
 
 
@@ -166,8 +166,8 @@
 /** Returns cleaned token based on delimiter, but not including delimiter. Also changes the pointer location
  * the beginning of the string. Tokens are newly allocated null terminated strings. */
-char* getToken(char **inString, char *delimiter, int *status)
+char* getToken(char **inString, char *delimiter, psS32 *status)
 {
     char *cleanToken = NULL;
-    int sLen = 0;
+    psS32 sLen = 0;
 
 
@@ -195,5 +195,5 @@
 /** Returns single parsed value as a double precision number. The input string must be cleaned and null
  * terminated. */
-double parseValue(char *inString, int *status)
+double parseValue(char *inString, psS32 *status)
 {
     char *end = NULL;
@@ -212,7 +212,7 @@
 
 /** Returns true or false. 'T', 't', '1', 'F', 'f', and '0' are acceptable, parsable variations. */
-bool parseBool(char *inString, int *status)
-{
-    bool value = false;
+psBool parseBool(char *inString, psS32 *status)
+{
+    psBool value = false;
 
 
@@ -229,10 +229,10 @@
 
 /** Returns parsed vector filled with with data. The input string must be null terminated. */
-psVector* parseVector(char *inString, psElemType elemType, int *status)
+psVector* parseVector(char *inString, psElemType elemType, psS32 *status)
 {
     char *end = NULL;
     char *saveValue = NULL;
-    int i = 0;
-    int numValues = 0;
+    psS32 i = 0;
+    psS32 numValues = 0;
     double value = 0.0;
     psVector *vec = NULL;
@@ -341,8 +341,8 @@
 
 
-psMetadata* psMetadataReadHeader(psMetadata* output, char *extName, int extNum, char *fileName)
-{
-    bool tempBool;
-    bool success;
+psMetadata* psMetadataReadHeader(psMetadata* output, char *extName, psS32 extNum, char *fileName)
+{
+    psBool tempBool;
+    psBool success;
     char keyType;
     char keyName[FITS_LINE_SIZE];
@@ -350,9 +350,9 @@
     char keyComment[FITS_LINE_SIZE];
     char fitsErr[MAX_STRING_LENGTH];
-    int i;
-    int hduType = 0;
-    int status = 0;
-    int numKeys = 0;
-    int keyNum = 0;
+    psS32 i;
+    psS32 hduType = 0;
+    psS32 status = 0;
+    psS32 numKeys = 0;
+    psS32 keyNum = 0;
     psMetadataType metadataItemType;
     fitsfile *fd = NULL;
@@ -449,7 +449,7 @@
 
 
-int psMetadataParseConfig(psMetadata** md, char *fileName, bool overwrite)
-{
-    bool tempBool;
+psS32 psMetadataParseConfig(psMetadata** md, char *fileName, psBool overwrite)
+{
+    psBool tempBool;
     char *line = NULL;
     char *strName = NULL;
@@ -458,7 +458,7 @@
     char *strComment = NULL;
     char *linePtr = NULL;
-    int status = 0;
-    int lineCount = 0;
-    int failedLines = 0;
+    psS32 status = 0;
+    psS32 lineCount = 0;
+    psS32 failedLines = 0;
     psF64 tempDbl = 0.0;
     psS32 tempInt = 0.0;
Index: trunk/psLib/src/collections/psVector.c
===================================================================
--- trunk/psLib/src/collections/psVector.c	(revision 2055)
+++ trunk/psLib/src/collections/psVector.c	(revision 2204)
@@ -10,6 +10,6 @@
 *  @author Robert DeSonia, MHPCC
 *
-*  @version $Revision: 1.28 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-07 19:51:30 $
+*  @version $Revision: 1.29 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-27 00:57:31 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -42,8 +42,8 @@
 // FUNCTION IMPLEMENTATION - PUBLIC
 
-psVector* psVectorAlloc(unsigned int nalloc, psElemType elemType)
+psVector* psVectorAlloc(psU32 nalloc, psElemType elemType)
 {
     psVector* psVec = NULL;
-    int elementSize = 0;
+    psS32 elementSize = 0;
 
     elementSize = PSELEMTYPE_SIZEOF(elemType);
@@ -64,7 +64,7 @@
 }
 
-psVector* psVectorRealloc(psVector* restrict in, unsigned int nalloc)
-{
-    int elementSize = 0;
+psVector* psVectorRealloc(psVector* restrict in, psU32 nalloc)
+{
+    psS32 elementSize = 0;
     psElemType elemType;
 
@@ -88,7 +88,7 @@
 }
 
-psVector* psVectorRecycle(psVector* restrict in, unsigned int n, psElemType type)
-{
-    int byteSize;
+psVector* psVectorRecycle(psVector* restrict in, psU32 n, psElemType type)
+{
+    psS32 byteSize;
 
     if (in == NULL) {
@@ -129,5 +129,5 @@
     }
 
-    int nElements = in->n;
+    psS32 nElements = in->n;
 
     out = psVectorRecycle(out, nElements, type);
@@ -136,5 +136,5 @@
         ps##INTYPE *inVec = in->data.INTYPE; \
         ps##OUTTYPE *outVec = out->data.OUTTYPE; \
-        for (int col=0;col<nElements;col++) { \
+        for (psS32 col=0;col<nElements;col++) { \
             *(outVec++) = *(inVec++); \
         } \
@@ -225,8 +225,8 @@
 psVector* psVectorSort(psVector* restrict outVector, const psVector* restrict inVector)
 {
-    int N = 0;
-    int elSize = 0;
-    void *inVec = NULL;
-    void *outVec = NULL;
+    psS32 N = 0;
+    psS32 elSize = 0;
+    psPtr inVec = NULL;
+    psPtr outVec = NULL;
     psElemType inType = 0;
 
@@ -311,5 +311,5 @@
 psVector* psVectorSortIndex(psVector* restrict outVector, const psVector* restrict inVector)
 {
-    int N = 0;
+    psS32 N = 0;
     psVector* tmpVector = NULL;
     psElemType inType = 0;
@@ -350,6 +350,6 @@
         ps##TYPE* tmpVec = tmpVector->data.TYPE;                              \
         ps##TYPE  diff;                                                       \
-        for(int i=0; i<N; i++) {                                              \
-            for(int j=0; j<N; j++) {                                          \
+        for(psS32 i=0; i<N; i++) {                                              \
+            for(psS32 j=0; j<N; j++) {                                          \
                 diff = absfcn(tmpVec[i] - inVec[j]);                          \
                 if(diff < maxError) {                                         \
Index: trunk/psLib/src/collections/psVector.h
===================================================================
--- trunk/psLib/src/collections/psVector.h	(revision 2055)
+++ trunk/psLib/src/collections/psVector.h	(revision 2204)
@@ -11,6 +11,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.24 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-10-06 21:30:52 $
+ *  @version $Revision: 1.25 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -33,6 +33,6 @@
 {
     psType type;                ///< Type of data.
-    unsigned int nalloc;        ///< Total number of elements available.
-    unsigned int n;             ///< Number of elements in use.
+    psU32 nalloc;        ///< Total number of elements available.
+    psU32 n;             ///< Number of elements in use.
 
     union {
@@ -49,5 +49,5 @@
         psC32* C32;             ///< Single-precision complex data.
         psC64* C64;             ///< Double-precision complex data.
-        psPTR V;                ///< Pointer to data.
+        psPtr V;                ///< Pointer to data.
     } data;                     ///< Union for data types.
 }
@@ -69,5 +69,5 @@
  */
 psVector* psVectorAlloc(
-    unsigned int nalloc,               ///< Total number of elements to make available.
+    psU32 nalloc,               ///< Total number of elements to make available.
     psElemType dataType                ///< Type of data to be held by vector.
 );
@@ -84,5 +84,5 @@
 psVector* psVectorRealloc(
     psVector* restrict psVec,          ///< Vector to reallocate.
-    unsigned int nalloc                ///< Total number of elements to make available.
+    psU32 nalloc                ///< Total number of elements to make available.
 );
 
@@ -101,5 +101,5 @@
     ///< taken to preserve the values.
 
-    unsigned int nalloc,               ///< Total number of elements to make available.
+    psU32 nalloc,               ///< Total number of elements to make available.
     psElemType type                    ///< the datatype of the returned vector
 );

Index: trunk/psLib/src/collections/psList.h
===================================================================
--- trunk/psLib/src/collections/psList.h	(revision 2055)
+++ trunk/psLib/src/collections/psList.h	(revision 2204)
@@ -10,6 +10,6 @@
  *  @ingroup LinkedList
  *
- *  @version $Revision: 1.15 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-09-09 02:23:27 $
+ *  @version $Revision: 1.16 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -17,5 +17,4 @@
 
 #include <pthread.h>                   // we need a mutex to make this stuff thread safe.
-#include <stdbool.h>                   // we use the bool type.
 
 #include "psCompare.h"
@@ -46,5 +45,5 @@
     struct psListElem* prev;           ///< previous link in list
     struct psListElem* next;           ///< next link in list
-    void *data;                        ///< real data item
+    psPtr data;                        ///< real data item
 }
 psListElem;
@@ -57,9 +56,9 @@
 typedef struct
 {
-    unsigned int size;                 ///< number of elements on list
+    psU32 size;                 ///< number of elements on list
     psListElem* head;                  ///< first element on list (may be NULL)
     psListElem* tail;                  ///< last element on list (may be NULL)
     psListElem* iter;                  ///< iteration cursor
-    unsigned int iterIndex;            ///< the numeric position of the iteration cursor in the list
+    psU32 iterIndex;            ///< the numeric position of the iteration cursor in the list
     pthread_mutex_t lock;              ///< mutex to lock a node during changes
 }
@@ -71,5 +70,5 @@
  */
 psList* psListAlloc(
-    void *data
+    psPtr data
     ///< initial data item; may be NULL if no an empty psList is desired
 )
@@ -81,20 +80,20 @@
  *                      NULL, the return value will also be NULL.
  */
-bool psListAdd(
+psBool psListAdd(
     psList* restrict list,             ///< list to add to (if NULL, nothing is done)
-    int location,                      ///< index, PS_LIST_HEAD, PS_LIST_TAIL, or numbered location.
-    void *data                         ///< data item to add.  If NULL, list is not modified.
+    psS32 location,                      ///< index, PS_LIST_HEAD, PS_LIST_TAIL, or numbered location.
+    psPtr data                         ///< data item to add.  If NULL, list is not modified.
 );
 
 /** Remove an item from a list.  If location parameter is PS_LIST_UNKNOWN,
  *
  *  @return bool        TRUE if element is successfully removed, otherwise FALSE.
  */
-bool psListRemove(
+psBool psListRemove(
     psList* restrict list,
     ///< list to remove element from
-    int location,
+    psS32 location,
     ///< index of item, or PS_LIST_UNKNOWN, PS_LIST_NEXT, PS_LIST_PREV, or numbered location.
-    void *data
+    psPtr data
     ///< if location is PS_LIST_UNKNOWN, data item to find and remove, otherwise this is ignored.
 );
@@ -102,12 +101,12 @@
 /** Retrieve an item from a list.
  *
  *  @return void*       the item corresponding to the location parameter.  If
  *                      location is invalid (e.g., a numbered index greater
  *                      than the list size or if the list is empty), a
  *                      NULL is returned.
  */
-void *psListGet(
+psPtr psListGet(
     psList* restrict list,             ///< list to retrieve element from
-    int location                       ///< index number, or PS_LIST_NEXT, PS_LIST_PREV, PS_LIST_UNKNOWN
+    psS32 location                       ///< index number, or PS_LIST_NEXT, PS_LIST_PREV, PS_LIST_UNKNOWN
 );
 
@@ -118,5 +117,5 @@
 void psListSetIterator(
     psList* restrict list,             ///< list to retrieve element from
-    int location                       ///< index number, PS_LIST_HEAD, or PS_LIST_TAIL
+    psS32 location                       ///< index number, PS_LIST_HEAD, or PS_LIST_TAIL
 );
 
@@ -124,9 +123,9 @@
  *  the next list position.
  *
  *  @return void*       the data item next on the list or NULL if the iterator
  *                      is already pointing to the last element or the list
  *                      parameter was NULL.
  */
-void *psListGetNext(
+psPtr psListGetNext(
     psList* restrict list              ///< list to retrieve element from
 );
@@ -135,9 +134,9 @@
  *  not move the iterator location.
  *
  *  @return void*       the data item cooresponding to current iterator
  *                      cursor position of the list, or NULL if either the
  *                      iterator is not valid or list parameter was NULL.
  */
-void *psListGetCurrent(
+psPtr psListGetCurrent(
     psList* restrict list              ///< list to retrieve element from
 );
@@ -146,9 +145,9 @@
  *  iterator to the previous list position.
  *
  *  @return void*       the data item previous on the list or NULL if the iterator
  *                      is already pointing to the first element or the list
  *                      parameter was NULL.
  */
-void *psListGetPrevious(
+psPtr psListGetPrevious(
     psList* restrict list              ///< list to retrieve element from
 );
@@ -81,20 +80,20 @@
 /** Remove an item from a list.  If location parameter is PS_LIST_UNKNOWN,
  *
- *  @return bool        TRUE if element is successfully removed, otherwise FALSE.
+ *  @return psBool        TRUE if element is successfully removed, otherwise FALSE.
  */
@@ -102,12 +101,12 @@
 /** Retrieve an item from a list.
  *
- *  @return void*       the item corresponding to the location parameter.  If
+ *  @return psPtr       the item corresponding to the location parameter.  If
  *                      location is invalid (e.g., a numbered index greater
  *                      than the list size or if the list is empty), a
@@ -124,9 +123,9 @@
  *  the next list position.
  *
- *  @return void*       the data item next on the list or NULL if the iterator
+ *  @return psPtr       the data item next on the list or NULL if the iterator
  *                      is already pointing to the last element or the list
  *                      parameter was NULL.
@@ -135,9 +134,9 @@
  *  not move the iterator location.
  *
- *  @return void*       the data item cooresponding to current iterator
+ *  @return psPtr       the data item cooresponding to current iterator
  *                      cursor position of the list, or NULL if either the
  *                      iterator is not valid or list parameter was NULL.
@@ -146,9 +145,9 @@
  *  iterator to the previous list position.
  *
- *  @return void*       the data item previous on the list or NULL if the iterator
+ *  @return psPtr       the data item previous on the list or NULL if the iterator
  *                      is already pointing to the first element or the list
  *                      parameter was NULL.
Index: trunk/psLib/src/collections/psMetadataIO.h
===================================================================
--- trunk/psLib/src/collections/psMetadataIO.h	(revision 2055)
+++ trunk/psLib/src/collections/psMetadataIO.h	(revision 2204)
@@ -9,6 +9,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.1 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-06 01:17:39 $
+*  @version $Revision: 1.2 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-27 00:57:30 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -50,5 +50,5 @@
     psMetadata* output,                ///< Resulting metadata from read.
     char *extName,                     ///< File name extension string.
-    int extNum,                        ///< File name extension number. Starts at 1.
+    psS32 extNum,                        ///< File name extension number. Starts at 1.
     char *fileName                     ///< Name of file to read.
 );
@@ -58,10 +58,10 @@
  *  Loads pre-defined settings by parsing a configuration file into a psMetadata structure.
  *
  *  @return int : Number of lines that failed to be read.
  */
-int psMetadataParseConfig(
+psS32 psMetadataParseConfig(
     psMetadata** md,                   ///< Resulting metadata from read.
     char *fileName,                    ///< Name of file to read.
-    bool overwrite                     ///< Allow overwrite of duplicate specifications.
+    psBool overwrite                     ///< Allow overwrite of duplicate specifications.
 );
 
@@ -58,10 +58,10 @@
  *  Loads pre-defined settings by parsing a configuration file into a psMetadata structure.
  *
- *  @return int : Number of lines that failed to be read.
+ *  @return psS32 : Number of lines that failed to be read.
  */